2004-08-27 Mikael Hallendal <micke@imendio.com>
authorhallski <hallski>
Thu, 26 Aug 2004 22:41:08 +0000
changeset 91 d51b8e4f43d9
parent 90 3f4b38614416
child 92 2307509710de
2004-08-27 Mikael Hallendal <micke@imendio.com> * Released 0.17 * NEWS: Updated for 0.17 * configure.in: Don't try to output mono Makefiles * docs/reference/tmpl/lm-connection.sgml: Updated * loudmouth/lm-connection.[ch]: - Changed the LmConnectionState enum to follow the rest of the API better.
ChangeLog
NEWS
configure.in
docs/reference/tmpl/lm-connection.sgml
loudmouth/lm-connection.c
loudmouth/lm-connection.h
--- a/ChangeLog	Tue Aug 24 23:37:38 2004 +0000
+++ b/ChangeLog	Thu Aug 26 22:41:08 2004 +0000
@@ -1,3 +1,14 @@
+2004-08-27  Mikael Hallendal  <micke@imendio.com>
+
+	* Released 0.17
+	
+	* NEWS: Updated for 0.17
+	* configure.in: Don't try to output mono Makefiles
+	* docs/reference/tmpl/lm-connection.sgml: Updated
+	* loudmouth/lm-connection.[ch]:
+	- Changed the LmConnectionState enum to follow the rest of the API 
+	  better.
+
 2004-08-25  Mikael Hallendal  <micke@imendio.com>
 
 	* loudmouth/lm-connection.[ch]: 
--- a/NEWS	Tue Aug 24 23:37:38 2004 +0000
+++ b/NEWS	Thu Aug 26 22:41:08 2004 +0000
@@ -1,3 +1,11 @@
+Changes in 0.17:
+----------------
+* Compile fixes (Sjoerd Simons
+* Depends on GLib 2.4
+* Fixed memory leak
+* Added support to work tunnel, using another JID than the connect server.
+* Support for keep alive packages
+
 Changes in 0.16:
 ----------------
 * Support for giving the context to which an LmConnection should run in
--- a/configure.in	Tue Aug 24 23:37:38 2004 +0000
+++ b/configure.in	Thu Aug 26 22:41:08 2004 +0000
@@ -182,8 +182,6 @@
 docs/reference/Makefile
 loudmouth/Makefile
 examples/Makefile
-mono/Makefile
-mono/loudmouth-sharp.pc
 loudmouth-1.0.pc
 loudmouth.spec])
 
--- a/docs/reference/tmpl/lm-connection.sgml	Tue Aug 24 23:37:38 2004 +0000
+++ b/docs/reference/tmpl/lm-connection.sgml	Thu Aug 26 22:41:08 2004 +0000
@@ -109,14 +109,14 @@
 
 <!-- ##### ENUM LmConnectionState ##### -->
 <para>
-
+Describes the current state of an #LmConnection.
 </para>
 
-@LM_CONNECTION_STATE_DISCONNECTED: 
-@LM_CONNECTION_STATE_CONNECTING: 
-@LM_CONNECTION_STATE_CONNECTED: 
-@LM_CONNECTION_STATE_AUTHENTICATING: 
-@LM_CONNECTION_STATE_AUTHENTICATED: 
+@LM_CONNECTION_STATE_CLOSED: The connection is closed.
+@LM_CONNECTION_STATE_OPENING: The connection is in the process of opening.
+@LM_CONNECTION_STATE_OPEN: The connection is open.
+@LM_CONNECTION_STATE_AUTHENTICATING: The connection is in the process of authenticating.
+@LM_CONNECTION_STATE_AUTHENTICATED: The connection is authenticated and is ready to start sending/receiving messages.
 
 <!-- ##### USER_FUNCTION LmResultFunction ##### -->
 <para>
--- a/loudmouth/lm-connection.h	Tue Aug 24 23:37:38 2004 +0000
+++ b/loudmouth/lm-connection.h	Thu Aug 26 22:41:08 2004 +0000
@@ -58,9 +58,9 @@
 } LmDisconnectReason;
 
 typedef enum {
-	LM_CONNECTION_STATE_DISCONNECTED,
-	LM_CONNECTION_STATE_CONNECTING,
-	LM_CONNECTION_STATE_CONNECTED,
+	LM_CONNECTION_STATE_CLOSED,
+	LM_CONNECTION_STATE_OPENING,
+	LM_CONNECTION_STATE_OPEN,
 	LM_CONNECTION_STATE_AUTHENTICATING,
 	LM_CONNECTION_STATE_AUTHENTICATED
 } LmConnectionState;
--- a/loudmouth/lm-connection.c	Tue Aug 24 23:37:38 2004 +0000
+++ b/loudmouth/lm-connection.c	Thu Aug 26 22:41:08 2004 +0000
@@ -594,7 +594,7 @@
 	req.ai_protocol = IPPROTO_TCP;
 	
 	connection->cancel_open = FALSE;
-	connection->state = LM_CONNECTION_STATE_CONNECTING;
+	connection->state = LM_CONNECTION_STATE_OPENING;
 	
 	if (connection->proxy) {
 		const gchar *proxy_server;
@@ -664,7 +664,7 @@
 		return;
 	}
 	
-	connection->state = LM_CONNECTION_STATE_DISCONNECTED;
+	connection->state = LM_CONNECTION_STATE_CLOSED;
 
 	if (connection->ssl) {
 		_lm_ssl_close (connection->ssl);
@@ -776,7 +776,7 @@
 {
 	gsize             bytes_written;
 	
-	if (connection->state < LM_CONNECTION_STATE_CONNECTING) {
+	if (connection->state < LM_CONNECTION_STATE_OPENING) {
 		g_set_error (error,
 			     LM_ERROR,
 			     LM_ERROR_CONNECTION_NOT_OPEN,
@@ -967,7 +967,7 @@
 	} 
 	else if (strcmp (type, "error") == 0) {
 		result = FALSE;
-		connection->state = LM_CONNECTION_STATE_CONNECTED;
+		connection->state = LM_CONNECTION_STATE_OPEN;
 	}
 	
 	lm_verbose ("AUTH reply: %d\n", result);
@@ -999,7 +999,7 @@
 	
 	lm_verbose ("Stream received: %s\n", connection->stream_id);
 	
-	connection->state = LM_CONNECTION_STATE_CONNECTED;
+	connection->state = LM_CONNECTION_STATE_OPEN;
 	
 	/* Check to see if the stream is correctly set up */
 	result = TRUE;
@@ -1116,7 +1116,7 @@
 	connection->disconnect_cb     = NULL;
 	connection->incoming_messages = g_queue_new ();
 	connection->cancel_open       = FALSE;
-	connection->state             = LM_CONNECTION_STATE_DISCONNECTED;
+	connection->state             = LM_CONNECTION_STATE_CLOSED;
 	connection->keep_alive_id     = 0;
 	
 	connection->id_handlers = g_hash_table_new_full (g_str_hash, 
@@ -1211,7 +1211,7 @@
 		return FALSE;
 	}
 	
-	while ((state = lm_connection_get_state (connection)) == LM_CONNECTION_STATE_CONNECTING) {
+	while ((state = lm_connection_get_state (connection)) == LM_CONNECTION_STATE_OPENING) {
 		if (g_main_context_pending (connection->context)) {
 			g_main_context_iteration (connection->context, TRUE);
 		} else {
@@ -1231,7 +1231,7 @@
  * lm_connection_cancel_open:
  * @connection: an #LmConnection to cancel opening on
  *
  * Cancels the open operation of a connection. The connection should be in the state #LM_CONNECTION_STATE_CONNECTING.
  **/
 void
 lm_connection_cancel_open (LmConnection *connection)
@@ -1464,7 +1464,7 @@
 {
 	g_return_val_if_fail (connection != NULL, FALSE);
 	
-	return connection->state >= LM_CONNECTION_STATE_CONNECTED;
+	return connection->state >= LM_CONNECTION_STATE_OPEN;
 }
 
 /**
@@ -1945,7 +1945,7 @@
 lm_connection_get_state (LmConnection *connection)
 {
 	g_return_val_if_fail (connection != NULL, 
-			      LM_CONNECTION_STATE_DISCONNECTED);
+			      LM_CONNECTION_STATE_CLOSED);
 
 	return connection->state;
 }
@@ -1231,7 +1231,7 @@
  * @connection: an #LmConnection to cancel opening on
  *
- * Cancels the open operation of a connection. The connection should be in the state #LM_CONNECTION_STATE_CONNECTING.
+ * Cancels the open operation of a connection. The connection should be in the state #LM_CONNECTION_STATE_OPENING.
  **/
 void